<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */


namespace Ozenie\Form;

use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\RepeatedType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Length;
use Symfony\Component\Validator\Constraints\Regex;

class RegisterType extends OzenieFormType
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('email', EmailType::class, [
                'label' => "Email" . '<span class="text-danger"> *</span>',
                'required' => true,
            ])
            ->add('password', RepeatedType::class, [
                'type' => PasswordType::class,
                'label' => "Password",
                'invalid_message' => 'Les champs de mot de passe doivent correspondre.',
                'options' => ['attr' => ['class' => 'password-field']],
                'required' => true,
                'first_options'  => ['label' => $this->t('Password') . '<span class="text-danger"> *</span>'],
                'second_options' => ['label' => $this->t('Repeat Password') . '<span class="text-danger"> *</span>'],
                'help' => "<ul>
                        <li>minimum neuf caractères</li>
                        <li>une majuscule</li>
                        <li>une minuscule</li>
                        <li>un chiffre</li>
                        <li>un caractère spécial</li>
                    </ul>",
                'constraints' => [
                    new Length([
                        'min' => 9, 'minMessage' => "Mot de passe invalide. Il doit avoir 9 caractères ou plus.",
                        'max' => 72, 'maxMessage' => "Il doit y avoir moins de 72 caractères"
                    ]),
                    new Regex(['pattern' => '/(?=.*\d)/', 'message' => "Il doit y avoir au moins un chiffre"]),
                    new Regex(['pattern' => '/(?=.*[a-z])/', 'message' => "Il doit y avoir au moins un caractère minuscule"]),
                    new Regex(['pattern' => '/(?=.*[A-Z])/', 'message' => "Il doit y avoir au moins un caractère majuscule"]),
                    new Regex(['pattern' => '/(?!.*\s)/', 'message' => "Il ne doit pas contenir d'espace blanc"]),
                    new Regex(['pattern' => '/(?=.*\W)/', 'message' => "Il doit y avoir au moins un caractère spécial"]),
                ]
            ])
            ->add('submit', SubmitType::class, [
                'label' => $this->t("Register"),
                "attr" => ["class" => "btn-default d-block m-auto"],
            ])
        ;
    }


    /**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => null,
        ]);
    }
}
