<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */


namespace Ozenie\Form;

use Context;
use Country;

use PrestaShopBundle\Form\Admin\Type\SwitchType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\CountryType;
use Symfony\Component\Form\Extension\Core\Type\RadioType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class UpdateType extends OzenieFormType
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $countries = [];
        foreach (Country::getCountries(Context::getContext()->language->getId(), true) as $country) {
            $countries[$country['name']] = $country['name'];
        }

        $conf = $this->userUpdConfig;
        $value = $conf->getConfiguration();

        $builder
            ->add($conf::SOCIAL_REASON, TextType::class, [
                'label' => $this->t('Raison social') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::SOCIAL_REASON],
                'required' => true,
            ])
            ->add($conf::ADDRESS_1, TextType::class, [
                'label' => $this->t('Adresse') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::ADDRESS_1],
                'required' => true,
            ])
            ->add($conf::ADDRESS_2, TextType::class, [
                'label' => $this->t('Complément d\'adresse'),
                'data'  => $value[$conf::ADDRESS_2],
                'required' => false,
            ])
            ->add($conf::POSTAL_CODE, TextType::class, [
                'label' => $this->t('Code Postal') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::POSTAL_CODE],
                'required' => true,
            ])
            ->add($conf::CITY, TextType::class, [
                'label' => $this->t('Ville') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::CITY],
                'required' => true,
            ])
            ->add($conf::COUNTRY, CountryType::class, [
                'label' => $this->t('Pays') . '<span class="text-danger mr-0"> *</span>',
                'choices' => $countries,
                'data'  => $value[$conf::COUNTRY],
                'required' => true,
            ])
            ->add($conf::PROVINCE_NAME, TextType::class, [
                'label' => $this->t('Province'),
                'data'  => $value[$conf::PROVINCE_NAME],
                'required' => false,
            ])
            ->add($conf::EMAIL, EmailType::class, [
                'label' => $this->t('Email') . '<span class="text-danger mr-0"> *</span>',
                'required' => true,
                'disabled' => true,
                'data'  => $value[$conf::EMAIL],
            ])
            ->add($conf::PHONE, TextType::class, [
                'label' => $this->t('Téléphone'),
                'data'  => $value[$conf::PHONE],
                'required' => false,
            ])
            ->add($conf::MOBILE_PHONE, TextType::class, [
                'label' => $this->t('Mobile'),
                'data'  => $value[$conf::MOBILE_PHONE],
                'required' => false,
            ])
            ->add($conf::FAX, TextType::class, [
                'label' => $this->t('Télécopie'),
                'data'  => $value[$conf::FAX],
                'required' => false,
            ])
            ->add($conf::WEBSITE, TextType::class, [
                'label' => $this->t('Site Web'),
                'data'  => $value[$conf::WEBSITE],
                'required' => false,
            ])
            ->add($conf::CONTACT_NAME, TextType::class, [
                'label' => $this->t('Nom de contact'),
                'data'  => $value[$conf::CONTACT_NAME],
                'required' => false,
            ])
            ->add($conf::SIRET, TextType::class, [
                'label' => $this->t('Siret') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::SIRET],
                'required' => true,
            ])
            ->add($conf::CODE_NAF, TextType::class, [
                'label' => $this->t('Code NAF') . '<span class="text-danger mr-0"> *</span>',
                'data'  => $value[$conf::CODE_NAF],
                'required' => true,
            ])
            ->add($conf::IBAN, TextType::class, [
                'label' => $this->t('IBAN'),
                'data'  => $value[$conf::IBAN],
                'required' => false,
            ])
            ->add($conf::BIC, TextType::class, [
                'label' => $this->t('BIC'),
                'data'  => $value[$conf::BIC],
                'required' => false,
            ])
            ->add($conf::TVA_INTRA, NumberType::class, [
                'label' => $this->t('TVA Intra Communautaire') . '<span class="text-danger mr-0"> *</span>',
                'data'  => (float) $value[$conf::TVA_INTRA],
                'required' => true,
            ])
            ->add($conf::ID_TVQ, TextType::class, [
                'label' => $this->t('identifiant TVQ'),
                'data'  => $value[$conf::ID_TVQ],
                'required' => false,
            ])
            ->add($conf::ID_TPS, TextType::class, [
                'label' => $this->t('identifiant TPS'),
                'data'  => $value[$conf::ID_TPS],
                'required' => false,
            ])
            ->add($conf::EX_TVA, SwitchType::class, [
                'label' => $this->t('Exonère TVA'),
                'data'  => (bool) $value[$conf::EX_TVA],
                'default_empty_data' => false,
                'required' => false,
            ])
            ->add('submit', SubmitType::class, [
                'label' => $this->t('Update'),
                "attr"  => ["class" => "btn-default d-block m-auto"],
            ])
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => null,
        ]);
    }
}
